@@ -6,10 +6,9 @@ OC.L10N.register(
     "Contacts" : "Contactos",
     "Loading contacts …" : "Cargando contactos ...",
     "Delete circle" : "Borrar círculo",
+    "General settings" : "Configuraciones generales",
     "Download" : "Descargar",
     "Send email" : "Enviar correo electrónico",
-    "Groups" : "Grupos",
-    "Group name" : "Nombre del grupo",
     "Circles" : "Círculos",
     "Create a new circle" : "Crear un nuevo círculo",
     "Rename" : "Renombrar",
