@@ -6,10 +6,9 @@ OC.L10N.register(
     "Contacts" : "مخاطبین",
     "Loading …" : "بارگذاری …",
     "Delete circle" : "حذف حلقه",
+    "General settings" : "تنظیمات عمومی",
     "Download" : "دانلود",
     "Send email" : "ارسال ایمیل",
-    "Groups" : "گروه ها",
-    "Group name" : "نام گروه",
     "Circles" : "حلقه ها",
     "Rename" : "تغییرنام",
     "Enabled" : "فعال شده",
@@ -51,7 +50,6 @@ OC.L10N.register(
     "Admin" : "مدیر",
     "Owner" : "مالک",
     "Users" : "کاربران",
-    "Emails" : "ایمیل",
     "Nickname" : "نام مستعار",
     "Detailed name" : "نام کامل",
     "Additional names" : "نام های دیگر",
