@@ -24,11 +24,16 @@ OC.L10N.register(
     "Add member" : "メンバーの追加",
     "Leave circle" : "サークルを退会する",
     "Delete circle" : "サークルを削除",
+    "Contacts settings" : "連絡先の設定",
+    "General settings" : "一般設定",
+    "Update avatars from social media" : "SNSでアバターをアップデート",
+    "(refreshed once per week)" : "(週に1回更新)",
+    "Address books" : "アドレス帳",
     "Download" : "ダウンロード",
     "Send email" : "メールを送信",
-    "Groups" : "グループ",
-    "Create a new group" : "新規グループを作成",
-    "Group name" : "グループ名",
+    "Contact groups" : "連絡先グループ",
+    "Create a new contact group" : "新規連絡先グループを作成",
+    "Contact group name" : "連絡先グループ名",
     "Circles" : "サークル",
     "Create a new circle" : "新しいサークルを作成する",
     "Show all groups" : "すべてのグループを表示",
@@ -70,12 +75,16 @@ OC.L10N.register(
     "Display name" : "表示名",
     "Last modified" : "最終更新日",
     "Sort by {sorting}" : "{sorting} で整列",
-    "Update avatars from social media" : "SNSでアバターをアップデート",
-    "(refreshed once per week)" : "(週に1回更新)",
-    "Address books" : "アドレス帳",
+    "Manages" : "管理",
+    "Oversees" : "統括",
     "An error happened during the config change" : "構成の変更中にエラーが発生しました",
     "Password protection" : "パスワード保護",
+    "Enforce password protection on files shared to this circle" : "このサークルへのファイル共有にはパスワードを強制します",
+    "Use a unique password for all shares to this circle" : "このサークルへのすべての共有に一意のパスワードを使用します",
+    "Unique password …" : "固有パスワード...",
     "Save" : "保存",
+    "Change unique password" : "固有パスワードを変更",
+    "Failed to save password. Please try again later." : "パスワードを保存できませんでした。後でもう一度やり直してください",
     "Circle name" : "サークル名",
     "Circle owned by {owner}" : "{owner}が所有しているサークル",
     "Request to join" : "参加リクエスト",
@@ -114,8 +123,11 @@ OC.L10N.register(
     "This contact is in read-only mode. You do not have permission to edit this contact." : "この連絡先は読み取り専用モードです。 この連絡先を編集する権限がありません。",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "編集しようとした連絡先が変更されました。 連絡先を手動で更新してください。 それ以上の編集は破棄されます。",
     "Address book" : "アドレス帳",
+    "Add contact to Birthday Calendar" : "誕生日カレンダーに連絡先を追加する",
+    "Exclude contact from Birthday Calendar" : "誕生日カレンダーから連絡先を除外する",
     "New contact" : "新しい連絡先",
     "Syntax error. Cannot open the contact." : "構文エラー。 連絡先を開けません",
+    "The contact does not exists on the server anymore." : "その連絡先はサーバーにはもう存在しません",
     "Unable to retrieve the contact from the server, please check your network connection." : "サーバーから連絡先を取得できないので、ネットワークの接続をご確認ください。",
     "An error occurred while trying to move the contact" : "連絡先の移動中にエラーが発生しました",
     "An error occurred while trying to copy the contact" : "連絡先のコピー中にエラーが発生しました",
@@ -135,7 +147,6 @@ OC.L10N.register(
     "Create circle" : "サークルを作成",
     "Loading members list …" : "メンバーリストを読み込んでいます…",
     "The list of members is only visible to members of this circle" : "メンバーのリストは、このサークルのメンバーにのみ表示されます",
-    "There is no member in this circle" : "このサークルにはメンバーがいません",
     "Add members" : "メンバーの追加",
     "Show circle details" : "サークル詳細を表示",
     "Add to {circle}" : "{circle} に追加",
@@ -155,6 +166,7 @@ OC.L10N.register(
     "Could not change the member level to {level}" : "メンバーレベルを{level}に変更できませんでした",
     "Could not accept membership request" : "メンバーシップリクエストを承諾できませんでした",
     "Chart" : "チャート",
+    "Select chart …" : "組織図を選択...",
     "Select type" : "タイプを選択",
     "Select Date" : "日付を選択",
     "Add contact in group" : "グループに連絡先を追加",
@@ -182,6 +194,7 @@ OC.L10N.register(
     "Could not copy link to the clipboard." : "クリップボードにコピーできませんでした",
     "Not grouped" : "グループ化されていません",
     "Recently contacted" : "最近連絡した",
+    "Organization chart" : "組織図",
     "Circles allow you to create groups with other users on a Nextcloud instance and share with them." : "サークルを使用すると、Nextcloudで他のユーザーとグループを作成し、それらと共有できます。",
     "Circle" : "サークル",
     "User" : "ユーザー",
@@ -202,7 +215,6 @@ OC.L10N.register(
     "Circle membership" : "サークルメンバーシップ",
     "Prevent circle from being a member of another circle" : "サークルが別のサークルのメンバーにならないようにする",
     "Users" : "ユーザー",
-    "Emails" : "メール",
     "Nickname" : "ニックネーム",
     "Detailed name" : "詳細名",
     "Additional names" : "ミドルネーム",
