@@ -22,14 +22,12 @@ OC.L10N.register(
     "Add member" : "Legg til et medlem",
     "Leave circle" : "Forlat sirkelen",
     "Delete circle" : "Slett sirkel",
+    "Contacts settings" : "Kontaktinnstillinger",
+    "General settings" : "Generelle innstillinger",
     "Download" : "Last ned",
     "Send email" : "Send e-post",
-    "Groups" : "Grupper",
-    "Create a new group" : "Opprett en ny gruppe",
-    "Group name" : "Gruppenavn",
     "Circles" : "Sirkler",
     "Create a new circle" : "Opprett en ny sirkel",
-    "Contacts settings" : "Kontaktinnstillinger",
     "Show all groups" : "Vis alle grupper",
     "Collapse groups" : "Kollapse grupper",
     "Show all circles" : "Vis alle sirkler",
@@ -98,7 +96,6 @@ OC.L10N.register(
     "Create circle" : "Opprett sirkel",
     "Loading members list …" : "Laster liste over medlemmer...",
     "The list of members is only visible to members of this circle" : "Listen over medlemmer er kun synlig for medlemmer av denne sirkelen",
-    "There is no member in this circle" : "Det finnes ingen medlemmer av denne sirkelen",
     "Add members" : "Legg til medlemmer",
     "Show circle details" : "Vis sirkeldetaljer",
     "Add to {circle}" : "Legg til i {circle}",
@@ -152,7 +149,6 @@ OC.L10N.register(
     "Circle membership" : "Sirkelmedlemskap",
     "Prevent circle from being a member of another circle" : "Hindre sirkel fra å kunne bli medlem av en annen sirkel",
     "Users" : "Brukere",
-    "Emails" : "E-poster",
     "Nickname" : "Kallenavn",
     "Detailed name" : "Detaljert navn",
     "Additional names" : "Ev. mellomnavn",
