@@ -24,11 +24,13 @@ OC.L10N.register(
     "Add member" : "添加成员",
     "Leave circle" : "离开圈子",
     "Delete circle" : "删除圈子",
+    "Contacts settings" : "联系人设置",
+    "General settings" : "一般设置",
+    "Update avatars from social media" : "从社交媒体更新头像",
+    "(refreshed once per week)" : "(每周刷新)",
+    "Address books" : "通讯录",
     "Download" : "下载",
     "Send email" : "发送邮件",
-    "Groups" : "群组",
-    "Create a new group" : "新建一个群组",
-    "Group name" : "分组名称",
     "Circles" : "圈子",
     "Create a new circle" : "新建一个圈子",
     "Show all groups" : "显示所有小组",
@@ -70,12 +72,16 @@ OC.L10N.register(
     "Display name" : "显示名称",
     "Last modified" : "上一次更改",
     "Sort by {sorting}" : "以 {sorting} 排序",
-    "Update avatars from social media" : "从社交媒体更新头像",
-    "(refreshed once per week)" : "(每周刷新)",
-    "Address books" : "通讯录",
+    "Manages" : "管理",
+    "Oversees" : "监督",
     "An error happened during the config change" : "更改配置时发生一个错误",
     "Password protection" : "密码保护",
+    "Enforce password protection on files shared to this circle" : "对分享到该圈子中的文件强制使用密码保护",
+    "Use a unique password for all shares to this circle" : "对分享到该圈子中的文件使用独一无二的密码",
+    "Unique password …" : "独一无二的密码 …",
     "Save" : "保存",
+    "Change unique password" : "修改独一无二的密码",
+    "Failed to save password. Please try again later." : "保存密码失败。请稍后重试。",
     "Circle name" : "圈子名称",
     "Circle owned by {owner}" : "圈子所有者为  {owner}",
     "Request to join" : "请求加入",
@@ -114,20 +120,22 @@ OC.L10N.register(
     "This contact is in read-only mode. You do not have permission to edit this contact." : "此联系人处于只读模式。 您无权编辑此联系人。",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "您尝试编辑的联系人已更改。 请手动刷新联系人。 任何进一步的编辑都不会被保存。",
     "Address book" : "地址簿",
+    "Add contact to Birthday Calendar" : "添加联系人到生日日历",
+    "Exclude contact from Birthday Calendar" : "从生日日历中排除联系人",
     "New contact" : "新建联系人",
     "Syntax error. Cannot open the contact." : "语法错误。不能打开联系人。",
-    "The contact doesn't exists anymore on the server." : "此联系人不再存在于此服务器上。",
+    "The contact does not exists on the server anymore." : "服务器上不再存在该联系人。",
     "Unable to retrieve the contact from the server, please check your network connection." : "无法从服务器取回联系人，请检查你的网络连接。",
     "An error occurred while trying to move the contact" : "尝试移动联系人时出错",
     "An error occurred while trying to copy the contact" : "尝试复制联系人时出错",
     "Search contacts …" : "搜索联系人 …",
     "Add to {group}" : "添加到 {group}",
-    "Remove {type}" : "移除 {类型}",
-    "Search {types}" : "搜索 {类型}",
+    "Remove {type}" : "移除 {type}",
+    "Search {types}" : "搜索 {types}",
     "Search for people to add" : "搜索要添加的人",
     "No results" : "无结果",
     "Add to group" : "添加到群组",
-    "Add {type}" : "添加  {类型}",
+    "Add {type}" : "添加  {type}",
     "New circle name" : "新的圈子名称",
     "Personal circle" : "个人圈子",
     "This circle will only be visible to you. Other members will not be able to see or use it." : "这个圈子仅对你可见。其他成员无法看见或使用它",
@@ -136,7 +144,6 @@ OC.L10N.register(
     "Create circle" : "创建圈子",
     "Loading members list …" : "加载成员列表中 ...",
     "The list of members is only visible to members of this circle" : "成员列表仅对这个圈子的成员可见",
-    "There is no member in this circle" : "这个圈子没有成员",
     "Add members" : "添加成员",
     "Show circle details" : "显示圈子详情",
     "Add to {circle}" : "添加到 {circle}",
@@ -144,7 +151,7 @@ OC.L10N.register(
     "Unable to get the results" : "无法获得结果",
     "Some members could not be added" : "无法添加一些成员",
     "There was an issue adding members to the circle" : "添加成员到这个圈子时出错",
-    "Accept membership request" : "接收成员身份请求",
+    "Accept membership request" : "接受成员身份请求",
     "Reject membership request" : "拒绝成员身份请求",
     "Manage level" : "管理级别",
     "Remove member" : "删除成员",
@@ -155,6 +162,8 @@ OC.L10N.register(
     "Could not delete the member {displayName}" : "无法删除成员 {displayName}",
     "Could not change the member level to {level}" : "无法更改成员级别到 {level}",
     "Could not accept membership request" : "无法接受成员身份请求",
+    "Chart" : "图表",
+    "Select chart …" : "选择图表 …",
     "Select type" : "选择类型",
     "Select Date" : "选择日期",
     "Add contact in group" : "添加联系人到群组",
@@ -182,7 +191,8 @@ OC.L10N.register(
     "Could not copy link to the clipboard." : "无法复制链接到剪贴板",
     "Not grouped" : "未分组",
     "Recently contacted" : "最近联系",
-    "Circles allow you to create groups with other users on a Nextcloud instance and share with them." : "Circles允许你在 Nextcloud 实例上与其他用户创建组并与他们分享。",
+    "Organization chart" : "组织图",
+    "Circles allow you to create groups with other users on a Nextcloud instance and share with them." : "Circles 允许你在 Nextcloud 实例上与其他用户创建组并与他们分享。",
     "Circle" : "圈子",
     "User" : "用户",
     "Group" : "小组",
@@ -202,7 +212,6 @@ OC.L10N.register(
     "Circle membership" : "圈子成员资格",
     "Prevent circle from being a member of another circle" : "防止圈子成为另一个圈子的成员",
     "Users" : "用户",
-    "Emails" : "电子邮件",
     "Nickname" : "昵称",
     "Detailed name" : "全名",
     "Additional names" : "其他名称",
@@ -237,6 +246,7 @@ OC.L10N.register(
     "Voice" : "语音",
     "Car" : "车",
     "Work pager" : "工作传呼机",
+    "Manager" : "经理",
     "Social network" : "社交网络",
     "Relationship to you" : "和您的关系",
     "Spouse" : "配偶",
@@ -249,7 +259,6 @@ OC.L10N.register(
     "Relative" : "关系",
     "Friend" : "朋友",
     "Colleague" : "同事",
-    "Manager" : "经理",
     "Assistant" : "助理",
     "Related contacts" : "相关联系人",
     "Agent" : "代理",
