@@ -24,14 +24,18 @@ OC.L10N.register(
     "Add member" : "添加成員",
     "Leave circle" : "離開社交圈子",
     "Delete circle" : "刪除社交圈子",
+    "Contacts settings" : " 通訊錄設定",
+    "General settings" : "一般設定",
+    "Update avatars from social media" : "從社群媒體更新虛擬化身大頭照",
+    "(refreshed once per week)" : "（每週重新整理一次）",
+    "Address books" : "通訊錄",
     "Download" : "下載",
     "Send email" : "傳送電郵",
-    "Groups" : "群組",
-    "Create a new group" : "建立新群組",
-    "Group name" : "群組名稱",
+    "Contact groups" : "聯絡群組",
+    "Create a new contact group" : "創建新聯絡人群組",
+    "Contact group name" : "聯絡人群組名稱",
     "Circles" : "社交圈子",
     "Create a new circle" : "創建新社交圈子",
-    "Contacts settings" : " 通訊錄設定",
     "Show all groups" : "顯示所有群組",
     "Collapse groups" : "收合群組",
     "Show all circles" : "顯示所有社交圈子",
@@ -71,9 +75,6 @@ OC.L10N.register(
     "Display name" : "顯示名稱",
     "Last modified" : "上次修改",
     "Sort by {sorting}" : "按 {sorting} 排序",
-    "Update avatars from social media" : "從社群媒體更新虛擬化身大頭照",
-    "(refreshed once per week)" : "（每週重新整理一次）",
-    "Address books" : "通訊錄",
     "Manages" : "管理",
     "Oversees" : "監督",
     "An error happened during the config change" : "配置更改期間發生錯誤",
@@ -122,6 +123,8 @@ OC.L10N.register(
     "This contact is in read-only mode. You do not have permission to edit this contact." : "此聯絡人處於唯讀模式。您無權編輯此聯絡人。",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "您嘗試編輯的聯絡人已變更。請手動重新整理聯絡人。任何進一步的編輯都會被丟棄。",
     "Address book" : "通訊錄",
+    "Add contact to Birthday Calendar" : "將聯絡人添加至生日日曆",
+    "Exclude contact from Birthday Calendar" : "從生日日曆中排除聯絡人",
     "New contact" : "新聯絡人",
     "Syntax error. Cannot open the contact." : "語法錯誤。無法開啟聯絡人。",
     "The contact does not exists on the server anymore." : "伺服器上不再存在該聯絡人。",
@@ -144,7 +147,7 @@ OC.L10N.register(
     "Create circle" : "創建社交圈子",
     "Loading members list …" : "正在加載成員清單 …",
     "The list of members is only visible to members of this circle" : "成員列表僅此圈子的成員可見",
-    "There is no member in this circle" : "此社交圈子中沒有任何成員",
+    "You currently have no access to the member list" : "您目前無權存取會員清單",
     "Add members" : "添加成員",
     "Show circle details" : "顯示社交圈子細節",
     "Add to {circle}" : "添加到 {circle}",
@@ -202,7 +205,7 @@ OC.L10N.register(
     "Member" : "成員",
     "Moderator" : "主持人",
     "Admin" : "管理員",
-    "Owner" : "所有者",
+    "Owner" : "擁有者",
     "Invites" : "邀請",
     "Anyone can request membership" : "任何人都可以申請加入",
     "Members need to accept invitation" : "會員需要接受邀請",
@@ -213,7 +216,7 @@ OC.L10N.register(
     "Circle membership" : "社交圈子會員",
     "Prevent circle from being a member of another circle" : "防止社交圈子成為另一個圈子的成員",
     "Users" : "用戶",
-    "Emails" : "電子郵件",
+    "Email addresses" : "電郵地址",
     "Nickname" : "暱稱",
     "Detailed name" : "詳細名稱",
     "Additional names" : "別名/中間名",
