@@ -24,14 +24,18 @@ OC.L10N.register(
     "Add member" : "新增成員",
     "Leave circle" : "離開小圈圈",
     "Delete circle" : "刪除小圈圈",
+    "Contacts settings" : "聯絡人設定",
+    "General settings" : "一般設定",
+    "Update avatars from social media" : "從社群媒體更新大頭照",
+    "(refreshed once per week)" : "（每週重新整理一次）",
+    "Address books" : "通訊錄",
     "Download" : "下載",
     "Send email" : "傳送電子郵件",
-    "Groups" : "群組",
-    "Create a new group" : "建立新群組",
-    "Group name" : "群組名稱",
+    "Contact groups" : "聯絡人群組",
+    "Create a new contact group" : "建立新聯絡人群組",
+    "Contact group name" : "聯絡人群組名稱",
     "Circles" : "小圈圈",
     "Create a new circle" : "建立新的小圈圈",
-    "Contacts settings" : "聯絡人設定",
     "Show all groups" : "顯示所有群組",
     "Collapse groups" : "折疊群組",
     "Show all circles" : "顯示所有小圈圈",
@@ -71,9 +75,6 @@ OC.L10N.register(
     "Display name" : "顯示名稱",
     "Last modified" : "上次修改",
     "Sort by {sorting}" : "按 {sorting} 排序",
-    "Update avatars from social media" : "從社群媒體更新大頭照",
-    "(refreshed once per week)" : "（每週重新整理一次）",
-    "Address books" : "通訊錄",
     "Manages" : "管理",
     "Oversees" : "監督",
     "An error happened during the config change" : "變更設定時發生錯誤",
@@ -122,6 +123,8 @@ OC.L10N.register(
     "This contact is in read-only mode. You do not have permission to edit this contact." : "此聯絡人處於唯讀模式。您無權編輯此聯絡人。",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "您嘗試編輯的聯絡人已變更。請手動重新整理聯絡人。任何進一步的編輯都會被丟棄。",
     "Address book" : "通訊錄",
+    "Add contact to Birthday Calendar" : "將聯絡人新增至生日行事曆",
+    "Exclude contact from Birthday Calendar" : "從生日行事曆排除聯絡人",
     "New contact" : "新聯絡人",
     "Syntax error. Cannot open the contact." : "語法錯誤。無法開啟聯絡人。",
     "The contact does not exists on the server anymore." : "伺服器上不再存在該聯絡人。",
@@ -144,7 +147,7 @@ OC.L10N.register(
     "Create circle" : "建立小圈圈",
     "Loading members list …" : "正在載入成員清單……",
     "The list of members is only visible to members of this circle" : "成員清單僅有此小圈圈的成員可見",
-    "There is no member in this circle" : "此小圈圈中沒有成員",
+    "You currently have no access to the member list" : "您目前無權存取成員清單",
     "Add members" : "新增成員",
     "Show circle details" : "顯示小圈圈詳細資訊",
     "Add to {circle}" : "新增至 {circle}",
@@ -213,7 +216,7 @@ OC.L10N.register(
     "Circle membership" : "小圈圈成員資格",
     "Prevent circle from being a member of another circle" : "避免小圈圈成為其他小圈圈的成員",
     "Users" : "使用者",
-    "Emails" : "電子郵件",
+    "Email addresses" : "電子郵件地址",
     "Nickname" : "暱稱",
     "Detailed name" : "詳細名稱",
     "Additional names" : "別名/中間名",
